<?php
namespace FM\Factory;

use Doctrine\ORM\EntityManager;

class FCMAnaliseConformidadeFactory
{ 
  protected $connection;
  protected $alias;
  
  public function __construct(EntityManager $entityManager) {
    $this->connection = $entityManager->getConnection();
    $this->alias = "c";
  }
  
  public function getCriterioNaoConformidadeByGestor($params) {
    $whereClausules = "";
    $useParams = false;
    if (array_key_exists("NRLOCALCLIENTE", $params)) {
      $whereClausules .= " AND loc.NRLOCALCLIENTE = :NRLOCALCLIENTE";
      $useParams = true;
    }
    if (array_key_exists("NRTIPOLOCALCLI", $params)) {
      $whereClausules .= " AND loc.NRTIPOLOCALCLI = :NRTIPOLOCALCLI";
      $useParams = true;
    }
    if (array_key_exists("NRSETOR", $params)) {
      $whereClausules .= " AND loc.NRSETOR = :NRSETOR";
      $useParams = true;
    }
    if (array_key_exists("DATEBEGIN", $params) || array_key_exists("DATEEND", $params)) {
      if (array_key_exists("DATEBEGIN", $params) && array_key_exists("DATEEND", $params)) {
        $whereClausules .= " AND TRUNC(c.DTHORAAGEND) BETWEEN TO_DATE('" . $params["DATEBEGIN"] . "' , 'DD/MM/YYYY') AND TO_DATE('" . $params["DATEEND"] . "' , 'DD/MM/YYYY')";
        unset($params["DATEBEGIN"]);
        unset($params["DATEEND"]);
      } else if (array_key_exists("DATEBEGIN", $params)) {
        $whereClausules .= " AND TRUNC(c.DTHORAAGEND) >= TO_DATE('" . $params["DATEBEGIN"] . "' , 'DD/MM/YYYY')";
        unset($params["DATEBEGIN"]);
      } else if (array_key_exists("DATEEND", $params)) {
        $whereClausules .= " AND TRUNC(c.DTHORAAGEND) <= TO_DATE('" . $params["DATEEND"] . "', 'DD/MM/YYYY')";
        unset($params["DATEEND"]);
      }
      $useParams = true;
    }
    $sql = "SELECT hc.NRFUNCIONARIOPAI, ct.DSCRITERIOTAREFA, func.NMFUNCIONARIO,
      func.NRFUNCIONARIO
      FROM FCM_CHECKLISTAGEND c
      INNER JOIN FCM_TAREFAAGEND ta
      ON c.NRCHECKLISTAGEND = ta.NRCHECKLISTAGEND
      INNER JOIN FCM_CRITERIOTARAGEND crit
      ON crit.NRTAREFAAGEND = ta.NRTAREFAAGEND
      INNER JOIN FCM_CRITERIOTAREFACHK critchk
      ON crit.NRCRITERIOTAREFACHK = critchk.NRCRITERIOTAREFACHK
      INNER JOIN FCM_CRITERIOTAREFA ct
      ON critchk.NRCRITERIOTAREFA = ct.NRCRITERIOTAREFA
      INNER JOIN FCM_FUNCIONARIO func
      ON func.NRFUNCIONARIO = c.NRFUNCIONARIO
      INNER JOIN FCM_FUNCIONARIOSHIERARQ hc
      ON hc.NRFUNCIONARIO = func.NRFUNCIONARIO
      INNER JOIN FCM_HIERARQUIAFUNC hcfunc
      ON hcfunc.NRHIERARQUIAFUNC = hc.NRHIERARQUIAFUNC
      INNER JOIN FCM_LOCALCLI loc
      ON loc.NRLOCALCLIENTE = c.NRLOCALCLIENTE
      WHERE hcfunc.IDATIVO LIKE 'S'";
      if ($useParams) {
        $sql .= $whereClausules;
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
      } else {
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
      }
  }

  public function getCriterioNaoConformidade($param) {
    $sql = "SELECT LC.NMLOCALCLIENTE || ' | ' || TLC.NMTIPOLOCALCLI AS NMLOCAL, CTAC.NMCRITERIOTARGERCHK
              FROM FCM_CRITERIOTARGERCHK CTAC
              JOIN FCM_TAREFAGERCHK TAC
                ON CTAC.NRTAREFAGERCHK = TAC.NRTAREFAGERCHK
              JOIN FCM_GERENCIAMENTOCHK GC
                ON TAC.NRGERENCIAMENTOCHK = GC.NRGERENCIAMENTOCHK
              JOIN FCM_LOCALCLI LC
                ON GC.NRLOCALCLIENTE = LC.NRLOCALCLIENTE
              JOIN FCM_TIPOLOCALCLI TLC
                ON LC.NRTIPOLOCALCLI = TLC.NRTIPOLOCALCLI
              JOIN FCM_CRITERIOTAREFACHK CTC  
                ON CTAC.NRCRITERIOTAREFACHK = CTC.NRCRITERIOTAREFACHK
              JOIN FCM_CRITERIOTAREFA CT
                ON CTC.NRCRITERIOTAREFA = CT.NRCRITERIOTAREFA
              WHERE CTAC.IDMARCADO = 'S' ".$param;
    $std = $this->connection->prepare($sql);
    $std->execute();
    return $std->fetchAll();
  }

  public function getPrincipalNaoConformidade($param) {
    $sql = "SELECT CTGC.NMCRITERIOTARGERCHK, COUNT(CTGC.NRCRITERIOTAREFACHK) AS QTDADE
              FROM FCM_CRITERIOTARGERCHK CTGC
              JOIN FCM_TAREFAGERCHK TGC
                ON CTGC.NRTAREFAGERCHK = TGC.NRTAREFAGERCHK
              WHERE IDMARCADO = 'S'".$param."
           GROUP BY CTGC.NRCRITERIOTAREFACHK, CTGC.NMCRITERIOTARGERCHK
           ORDER BY QTDADE DESC";
    $std = $this->connection->prepare($sql);
    $std->execute();
    return $std->fetchAll();
  }
}