<?php
namespace FM\Service;

use FM\Factory\DashboardFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Zeedhi\Framework\DataSource\DataSet;

class DashboardService {

    protected $DashboardFactory;
    protected $Environment;
    protected $newCode;

    public function __construct (DashboardFactory $DashboardFactory, Environment $Environment, NewCode $newCode) {
        $this->DashboardFactory  = $DashboardFactory;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
    }

    // responsável por retornar os dados de limpeza finalizada do dashboard
    public function getDadosLimpezaFinalizada($params){
        $usersHierarchyList = implode(',', $params); // nr's dos usuários da hierarquia abaixo do usuário logado

        $selectDadosLimpezaFinalizada = $this->DashboardFactory->getDadosLimpezaFinalizada($usersHierarchyList);

        return $selectDadosLimpezaFinalizada;
    }

    // responsável por retornar os dados de tarefa atrasada do dashboard
    public function getDadosTarefaAtrasada($params){
        $usersHierarchyList = implode(',', $params); // nr's dos usuários da hierarquia abaixo do usuário logado

        $selectDadosTarefaAtrasada = $this->DashboardFactory->getDadosTarefaAtrasada($usersHierarchyList);

        return $selectDadosTarefaAtrasada;
    }

    // responsável por retornar os dados de tarefa finalizada do dashboard
    public function getDadosTarefaConcluida($params){
        $usersHierarchyList = implode(',', $params); // nr's dos usuários da hierarquia abaixo do usuário logado

        $selectTarefaConcluida = $this->DashboardFactory->getDadosTarefaConcluida($usersHierarchyList);
        return $selectTarefaConcluida;
    }

    public function getDadosProgress($params){
        $usersHierarchyList = implode(',', $params); // nr's dos usuários da hierarquia abaixo do usuário logado

        $countTarefasConcluidas = $this->DashboardFactory->countTarefasConcluidas($usersHierarchyList);
        $countTarefas  = $this->DashboardFactory->countTarefas($usersHierarchyList);
        return[$countTarefasConcluidas,$countTarefas];
    }

    // requisição para retorno dos dados para o card (Ultimas Tarefas Realizadas) Dashboard Supervisor
    public function getDadosUltimasTarefas($param, $paramsUsers) {
        $parametroFiltro = '';
        if ($param['selectLocal'] != '' && $param['selectLocal'] != null && $param["selectData"] != null && $param["selectData"] != '') {
            $corte = substr($param["selectData"],0,5);
           $parametroFiltro = " AND ULTTAR.NRLOCALCLIENTE = ".$param['selectLocal']."AND TRUNC(ULTTAR.DTULTATU) = TO_DATE('".$corte."', 'DD/MM')";
        }
        else if($param['selectLocal'] == '' && $param["selectData"] != null && $param["selectData"] != ''){
            $corte = substr($param["selectData"],0,5);
            $parametroFiltro = " AND TRUNC(ULTTAR.DTULTATU) = TO_DATE('".$corte."', 'DD/MM')";
        } else if($param['selectLocal'] != '' && $param['selectLocal'] != null && $param["selectData"] == ''){
            $parametroFiltro = " AND ULTTAR.NRLOCALCLIENTE = ".$param['selectLocal'];
        }
        $usersHierarchyList = implode(',', $paramsUsers);
        $selectDadosChecagemLimpeza = $this->DashboardFactory->getDadosUltimasTarefas($parametroFiltro, $usersHierarchyList);

        return $selectDadosChecagemLimpeza;
    }
    // requisição para retorno dos dados para o card (Resumo de Tarefas) Dashboard Supervisor(Tarefas Diárias)
    public function getDadosResumoTarefas($param, $paramsUsers) {
        $parametroFiltro = '';
        if ($param['selectLocal'] != '' && $param['selectLocal'] != null && $param["selectData"] != null && $param["selectData"] != '') {
           $corte = substr($param["selectData"],0,5);
           $parametroFiltro = " AND ULTTAR.NRLOCALCLIENTE = ".$param['selectLocal']."AND TRUNC(ULTTAR.DTULTATU) = TO_DATE('".$corte."', 'DD/MM')";
        }
        else if($param['selectLocal'] == '' && $param["selectData"] != null && $param["selectData"] != ''){
            $corte = substr($param["selectData"],0,5);
            $parametroFiltro = " AND TRUNC(ULTTAR.DTULTATU) = TO_DATE('".$corte."', 'DD/MM')";
        } else if($param['selectLocal'] != '' && $param['selectLocal'] != null && $param["selectData"] == ''){
            $parametroFiltro = " AND ULTTAR.NRLOCALCLIENTE = ".$param['selectLocal'];
        }

        $usersHierarchyList = implode(',', $paramsUsers);
        $selectDadosChecagemLimpeza = $this->DashboardFactory->getDadosResumoTarefas($parametroFiltro, $usersHierarchyList);

        return $selectDadosChecagemLimpeza;
    }

    // requisição para retorno dos dados do grafico Tarefas Realizadas Dashboard Supervisor
    public function getDadosChartTarefas($param) {
        $usersHierarchyList = implode(',', $param);

        $selectDadosGraficos = $this->DashboardFactory->getDadosChartTarefas($usersHierarchyList);

        return $selectDadosGraficos;
    }

    // requisição para retorno dos dados para o grafico Não Conformidades Dashboard Supervisor
    public function getDadosChartNaoConformidades($param) {
        $usersHierarchyList = implode(',', $param);

        $dadosChartNaoConformidades = $this->DashboardFactory->getDadosChartNaoConformidades($usersHierarchyList);

        return $dadosChartNaoConformidades;
    }

    // requisição para retorno dos dados para grafico Progresso Diario Dashboard Supervisor(Tarefas Diárias)
    public function getDadosChartProgressoDiario($usersHierarchyList) {

        $dadosChartProgressoDiario = $this->DashboardFactory->countTarefasConcluidasDia($usersHierarchyList);

        return $dadosChartProgressoDiario;
    }

    // ------ REQUISIÇÕES DA TELA DE DASHBOARD (GERENCIAL) ----------

    public function setActivities() {

        $activities = $this->DashboardFactory->setActivities();
        return $activities;
    }

    public function getLocals($id) {

        $locals = $this->DashboardFactory->getLocals($id);
        return $locals;
    }

    public function dataBaseChartBarUnconformities($parametro) {

        $param = '';
        $paramAct = '';

        if ($parametro['selectUnit'] != '' && $parametro['selectUnit'] != null) {
            $param = " AND NMPAI.NRLOCALCLIENTE = ".$parametro['selectUnit'];
        }

        if ($parametro['selectService'] != '' && $parametro['selectService'] != null) {
             $paramAct = " WHERE AC.NRATIVIDADE = ".$parametro['selectService'];
        }

        if ($parametro['selectLocal'] != '' && $parametro['selectLocal'] != null) {
             $param = " AND LC.NRLOCALCLIENTE = ".$parametro['selectLocal'];
        }


        $dbcb = $this->DashboardFactory->dataBaseChartBarUnconformities($param, $paramAct);
        return $dbcb;
    }

    public function dataBaseChartPieClean($parametro) {
        $param = '';
        $paramAct = '';

        if ($parametro['selectUnit'] != '' && $parametro['selectUnit'] != null) {
            $param = " AND NMPAI.NRLOCALCLIENTE = ".$parametro['selectUnit'];
        }

        if ($parametro['selectService'] != '' && $parametro['selectService'] != null) {
             $paramAct = " WHERE AC.NRATIVIDADE = ".$parametro['selectService'];
        }

        if ($parametro['selectLocal'] != '' && $parametro['selectLocal'] != null) {
             $param = " AND LC.NRLOCALCLIENTE = ".$parametro['selectLocal'];
        }

        $dbcp = $this->DashboardFactory->dataBaseChartPieClean($param, $paramAct);
        return $dbcp;
    }

    public function dataBaseChartBarAvgTime($parametro) {
        $param = '';
        $paramAct = '';

        if ($parametro['selectUnit'] != '' && $parametro['selectUnit'] != null) {
            $param = "  AND LCPAI.NRLOCALCLIENTEPAI = ".$parametro['selectUnit'];
        }

        if ($parametro['selectService'] != '' && $parametro['selectService'] != null) {
             $paramAct = " WHERE AC.NRATIVIDADE = ".$parametro['selectService'];
        }

        if ($parametro['selectLocal'] != '' && $parametro['selectLocal'] != null) {
             $param = " AND LC.NRLOCALCLIENTE = ".$parametro['selectLocal'];
        }

        $dbcp = $this->DashboardFactory->dataBaseChartBarAvgTime($param, $paramAct);
        return $dbcp;
    }

    public function dataBaseChartPieUnit($parametro) {
        // debugApi([$parametro]);
        $param = '';
        $paramAct = '';

        if ($parametro['selectUnit'] != '' && $parametro['selectUnit'] != null) {
            $param = " AND NMPAI.NRLOCALCLIENTE = ".$parametro['selectUnit'];
        }

        if ($parametro['selectService'] != '' && $parametro['selectService'] != null) {
             $paramAct = " WHERE AC.NRATIVIDADE = ".$parametro['selectService'];
        }

        if ($parametro['selectLocal'] != '' && $parametro['selectLocal'] != null) {
             $param = " AND FCM_LOCALCLI.NRLOCALCLIENTE = ".$parametro['selectLocal'];
        }

        $dbcp = $this->DashboardFactory->dataBaseChartPieUnit($param, $paramAct);
        return $dbcp;
    }

    public function latestReports() {

        $reports = $this->DashboardFactory->latestReports();
        return $reports;
    }
    
    public function percentageTasks($parametro) {
      $usersIds = implode(',',$parametro['usersIds']); // Transforma o array em uma string com os ids
      $values = array (
          $this->DashboardFactory->percentageAllTasks($usersIds),
          $this->DashboardFactory->percentageTasksCompleted($usersIds)
        );
        return $values;
    }
    
    public function tasksCompleted($parametro) {
      $usersIds = implode(',',$parametro['usersIds']); // Transforma o array em uma string com os ids

      $tasks = $this->DashboardFactory->tasksCompleted($usersIds);
      return $tasks;
    }
    
    public function tasksLate($parametro) {
      $usersIds = implode(',',$parametro['usersIds']);

      $tasksLate = $this->DashboardFactory->tasksLate($usersIds);
      return $tasksLate;
    }
    
    public function lastTasksPerformed($parametro) {
      $usersIds = implode(',',$parametro['usersIds']); // Transforma o array em uma string com os ids

      $lastTask = $this->DashboardFactory->lastTasksPerformed($usersIds);
      return $lastTask;
    }
    
    public function dataBaseChartPie($parametro) {
      $usersIds = implode(',',$parametro['usersIds']);

      $dbcp = $this->DashboardFactory->dataBaseChartPie($usersIds);
      // debugApi([$dbcp]);
      return $dbcp;
    }
    
    public function dataBaseChartBar($parametro) {
      $usersIds = implode(',',$parametro['usersIds']);

      $dbcb = $this->DashboardFactory->dataBaseChartBar($usersIds);
      return $dbcb;
    }
}