import Vue from 'vue';
import Router from 'vue-router';
import { Router as RouterDirect, Config, Http } from '@zeedhi/core';
import { TekLibLocalStorage } from '@zeedhi/tek-lib';
import { LoadingService } from '@zeedhi/common';
import { ZdPage } from '@zeedhi/vue';
import Store from './store';

Vue.use(Router);

const router = new Router({
  mode: 'history',
  base: process.env.BASE_URL,
  routes: [
    {
      path: '/',
      name: 'home',
      component: () => import('./views/Home.vue'),
    },
    {
      name: 'NãoConformidades',
      path: '/Analise_nao_conformidedade',
      component: ZdPage,
      props: {
        path: 'FCMAnaliseNaoConformidade',
        local: true,
      },
    },
    {
      name: 'Tarefa',
      path: '/Tarefas',
      component: ZdPage,
      props: {
        path: 'FCMTarefas',
        local: true,
      },
    },
    {
      name: 'DashboardSensor',
      path: '/DashboardSensor',
      component: ZdPage,
      props: {
        path: 'sensor/layout_dashboardSensor',
        local: true,
      },
    },
    {
      name: 'ContadorSentidoUnico',
      path: '/SentidoUnico',
      component: ZdPage,
      props: {
        path: 'sensor/layout_sentidoUnico',
        local: true,
      },
    },
    {
      name: 'ContadorSentidoDuplo',
      path: '/SentidoDuplo',
      component: ZdPage,
      props: {
        path: 'sensor/layout_sentidoDuplo',
        local: true,
      },
    },
    {
      name: 'ContadorSentidoGeral',
      path: '/SentidoGeral',
      component: ZdPage,
      props: {
        path: 'sensor/layout_sentidoGeral',
        local: true,
      },
    },
    {
      name: 'Calendario',
      path: '/Calendario',
      component: ZdPage,
      props: {
        path: 'FCMCalendar',
        local: true,
      },
    },
    {
      name: 'LogTransferencia',
      path: '/Log',
      component: ZdPage,
      props: {
        path: 'FCMHistoricoTransferencia',
        local: true,
      },
    },
    {
      name: 'Cadastramento_tarefas',
      path: '/Cadastramento',
      component: ZdPage,
      props: {
        path: 'cadastramentoTarefas',
        local: true,
      },
    },
    {
      path: '/Relatorio',
      component: ZdPage,
      props: {
        path: 'Relatorios',
        local: true,
      },
    },
    {
      name: 'test',
      path: '/test',
      component: ZdPage,
      props: {
        path: 'test',
        local: true,
      },
    },
    {
      path: '/zeedhi',
      name: 'zeedhi',
      component: ZdPage,
      props: () => ({
        path: 'zeedhi',
        local: true,
      }),
    },
    {
      path: '/auth/login',
      name: 'login',
      component: ZdPage,
      props: () => ({
        path: 'login',
        local: true,
      }),
    },
    {
      path: '*',
      component: ZdPage,
      props: {
        path: 'notfound',
        local: true,
      },
    },
    {
      path: '/tipoLocal/:nrtipolocalcli',
      component: ZdPage,
      props: {
        path: 'tipoLocal',
        local: true,
      },
    },
    {
      name: 'Novo Checklit',
      path: '/cadastroNovoChecklist',
      component: ZdPage,
      props: {
        path: 'cadastroNovoChecklist',
        local: true,
      },
    },
    {
      path: '/localAtendimento',
      component: ZdPage,
      props: {
        path: 'localAtendimento',
        local: true,
      },
    },
    {
      path: '/localAtendimento/:nr',
      component: ZdPage,
      props: {
        path: 'localAtendimento',
        local: true,
      },
    },
    {
      path: '/checklist',
      component: ZdPage,
      props: {
        path: 'checklist',
        local: true,
      },
    },
    {
      path: '/dashboard',
      component: ZdPage,
      props: {
        path: 'dashboard',
        local: true,
      },
    },
    {
      path: '/dashboardSupervisor',
      component: ZdPage,
      props: {
        path: 'dashboardSupervisor',
        local: true,
      },
    },
    {
      path: '/dashboardGerencial',
      component: ZdPage,
      props: {
        path: 'dashboardGerencial',
        local: true,
      },
    },
    {
      path: '/editChecklist/:nr',
      component: ZdPage,
      props: {
        path: 'editChecklist',
        local: true,
      },
    },
    {
      path: '/gerenciarLocais',
      component: ZdPage,
      props: {
        path: 'gerenciarLocais',
        local: true,
      },
    },
    {
      path: '/agrupamentoSimples/:bloco',
      component: ZdPage,
      props: {
        path: 'agrupamentoSimples',
        local: true,
      },
    },
    {
      path: '/funcionarios',
      component: ZdPage,
      props: {
        path: 'funcionarios',
        local: true,
      },
    },
    {
      path: '/perfilDeAcesso',
      component: ZdPage,
      props: {
        path: 'perfilDeAcesso',
        local: true,
      },
    },
    {
      path: '/vistorias',
      component: ZdPage,
      props: {
        path: 'vistorias',
        local: true,
      },
    },
    {
      path: '/vistorias/detalhes/:id',
      component: ZdPage,
      props: {
        path: 'vistoriaDetalhes',
        local: true,
      },
    },
    {
      path: '/Sensores',
      component: ZdPage,
      props: {
        path: 'parametrosSensor',
        local: true,
      },
    },
    {
      path: '/grafico',
      component: ZdPage,
      props: {
        path: 'grafico',
        local: true,
      },
    },
    {
      path: '/hierarquias',
      component: ZdPage,
      props: {
        path: 'hierarquias',
        local: true,
      },
    },
    {
      path: '/gerarGrafico',
      component: ZdPage,
      props: {
        path: 'gerarGrafico',
        local: true,
      },
    },
    {
      path: '/hierarquias/detalhes/:id',
      component: ZdPage,
      props: {
        path: 'hierarquiaDetalhes',
        local: true,
      },
    },
    {
      path: '/solicitacoesDeTarefas',
      component: ZdPage,
      props: {
        path: 'tarefasSolicitacoes',
        local: true,
      },
    },
    {
      path: '/solicitacoesDeTarefas/detalhes/:id',
      component: ZdPage,
      props: {
        path: 'tarefasSolicitacaoDetalhes',
        local: true,
      },
    },
    {
      path: '/editGrafico/:nr',
      component: ZdPage,
      props: {
        path: 'editGrafico',
        local: true,
      },
    },
    {
      path: '/apontamento',
      component: ZdPage,
      props: {
        path: 'apontamento',
        local: true,
      },
    },
    {
      path: '/registroHoras/:nr',
      component: ZdPage,
      props: {
        path: 'registroHoras',
        local: true,
      },
    },
    {
      name: 'Adicionar ou editar Checklit',
      path: '/detalhesChecklist',
      component: ZdPage,
      props: {
        path: 'layout_checklist',
        local: true,
      },
    },
    {
      name: 'businessPartner',
      path: '/parceiro_de_negocio',
      component: ZdPage,
      props: {
        path: 'BusinessPartner/businessPartner',
        local: true,
      },
    },
    {
      name: 'businessPartnerInformation',
      path: '/informacoes_parceiros',
      component: ZdPage,
      props: {
        path: 'BusinessPartner/businessPartnerInformation',
        local: true,
      },
    },
    {
      name: 'Tarefas Recorrentes',
      path: '/tarefaRecorrente',
      component: ZdPage,
      props: {
        path: 'layout_tarefaRecorrente',
        local: true,
      },
    },
    {
      name: 'Parametrização Geral',
      path: '/parametrizacoes',
      component: ZdPage,
      props: {
        path: 'layout_parametrizacaoGeral',
        local: true,
      },
    },
    {
      name: 'Relatorio Customizavel Tarefas',
      path: '/relatorio_customizavel_tarefas',
      component: ZdPage,
      props: {
        path: 'relatorios/relatorio_customizavel_tarefas',
        local: true,
      },
    },
    {
      name: 'Relatorio Customizavel Vistorias',
      path: '/relatorio_customizavel_vistorias',
      component: ZdPage,
      props: {
        path: 'relatorios/relatorio_customizavel_vistorias',
        local: true,
      },
    },
    {
      path: '/modules/:module/:page',
      name: 'microservice',
      component: () => import('./views/Microservice.vue'),
    },
    {
      path: '*',
      component: ZdPage,
      props: {
        path: 'notfound',
        local: true,
      },
    },
  ],
});

const isOpeningNewModule = function isOpeningNewModule(to: any, from: any) {
  const isFromProduct = (to.name === 'microservice' && from.name !== 'microservice');
  // eslint-disable-next-line max-len
  const isFromAnotherModule = ((to.name === 'microservice' && from.name === 'microservice') && to.path.split('/')[2] !== from.path.split('/')[2]);
  const isNotLoginRoute = (to.fullPath !== Config.env.modules.login.routePath);
  return ((isFromProduct || isFromAnotherModule) && isNotLoginRoute);
};

// eslint-disable-next-line max-len
const callLibStartSessionFromModule = async function callLibStartSessionFromModule(to: any) {
  const data = {
    USER: localStorage.getItem('LOGIN_USER'),
    LOGIN_LANGUAGE: localStorage.getItem('LOGIN_LAGUAGE'),
    LOGIN_TOKEN: localStorage.getItem('LOGIN_TOKEN'),
  };
  await Http.post(`${Config.env.modules[to.path.split('/')[2]].endPoint}/lib_startSession`, data);
};

router.beforeEach(async (to, from, next) => {
  if (isOpeningNewModule(to, from)) {
    try {
      LoadingService.show();
      await callLibStartSessionFromModule(to);
      LoadingService.hide();
    } catch (e) {
      LoadingService.hide();
    }
  }

  /** open old application - init */
  if (window.parent !== window && to.name !== 'token-error' && to.name !== 'microservice') { // if application is called inside a iframe
    if (to.query.token) {
      // if token was passed
      localStorage.setItem('LOGIN_TOKEN', to.query.token.toString());
      localStorage.setItem('LOGIN_USER', to.query.user.toString());
      localStorage.setItem('LOGIN_LANGUAGE', to.query.languange.toString());
      localStorage.setItem('PRODUCT_ID', to.query.productId.toString());
      if (to.query.hash !== '0') {
        localStorage.setItem('LOGIN_HASH', to.query.hash.toString());
      }
      Store.commit('setAppLoginToken', to.query.token);
      Store.commit('setAppDisplayOptions', { menu: to.query.menu, header: to.query.header });
    }

    if (!Store.state!.appLoginToken) {
      // if there is no token... redirect to another page
      Store.commit('setAppDisplayOptions', { menu: '0', header: '0' });
      next('/token-error');
      return;
    }

    // remove parameters from requested page
    delete to.query.menu;
    delete to.query.header;
    delete to.query.token;

    TekLibLocalStorage.setItem('IS_NEXT', false);
    TekLibLocalStorage.setItem('LOGIN_KEEP_CONNECTED', 'Yes');
    TekLibLocalStorage.removeItem('routeParams');

    next();
  } else {
    TekLibLocalStorage.setItem('IS_NEXT', true);
  }
  /** open old application - end */

  if (to.path !== Config.env.loginRoutePath && !localStorage.getItem('LOGIN_TOKEN')) {
    next(Config.env.loginRoutePath);
  } else if (to.path === Config.env.loginRoutePath && localStorage.getItem('LOGIN_TOKEN')) {
    next(Config.env.baseUrl);
  } else {
    if (to.path !== Config.env.loginRoutePath && localStorage.getItem('LOGIN_TOKEN')) {
      const dashboards: any = { O: '/dashboard', S: '/dashboardSupervisor', G: '/dashboardGerencial' };
      const rotaDash = dashboards[<string>localStorage.getItem('IDTIPODASHBOARD')];
      if (to.path.includes('dashboard') && to.path !== rotaDash) {
        RouterDirect.replace(rotaDash);
      }
      if (to.path !== '/localAtendimento/edit' && to.path !== '/localAtendimento/add') {
        localStorage.removeItem('dadosToEdit');
      } else {
        const dados = JSON.parse(<string>localStorage.getItem('dadosToEdit')) || [];
        if (dados.length > 0) {
          dados.setLocalCli = true;
        }
        window.localStorage.setItem('dadosToEdit', JSON.stringify(dados));
      }
    }
    next();
  }
});

router.afterEach((to, from) => {
  const htmlElement = document.getElementsByTagName('html')[0];
  if (to.name === 'microservice') {
    htmlElement.setAttribute('microservice', '');
    Store.commit('setRouterParams', to.params);
    const frame = (document.getElementById('microservice-frame') as HTMLIFrameElement);
    if (frame && frame.contentWindow && to.path.split('/')[2] === from.path.split('/')[2]) {
      frame.contentWindow.postMessage({
        type: 'microservice-route-change',
        routerParams: to.params,
      }, `${Config.env.modules[to.path.split('/')[2]].baseUrl}`);
    }
    window.document.title = `${Config.env.product.name} - ${to.params.page}`;
  } else {
    htmlElement.removeAttribute('microservice');
    window.document.title = Config.env.product.name;
  }

  if (to.name === 'login') {
    htmlElement.setAttribute('login', '');
  } else {
    htmlElement.removeAttribute('login');
  }
});

export const { VUE_APP_BASE_URL } = process.env;

export const getRoutePath = () => {
  const { currentRoute } = router;
  const { path } = currentRoute;
  return path;
};

export const getRouteParams = () => {
  const { currentRoute } = router;
  const { params } = currentRoute;
  return params;
};

export default router;
